@@ -26,7 +26,7 @@ impl<T> Publisher for FlowableJust<T> {
     type Item = T;
 
     fn subscribe<E, S: Subscriber<Item = Self::Item, Error = E>>(self, subscriber: S) {
-        ScalarSubscription::new(self.t, subscriber).on_subscribe();
+        subscriber.on_subscribe(&ScalarSubscription::new(self.t, &subscriber));
     }
 }
 
@@ -36,7 +36,9 @@ mod tests {
 
     #[test]
     fn it_works() {
-        let flowable = just(1);
-        flowable.subscribe(MockSubscriber::default());
+        for i in vec![0, 1, u64::MAX].into_iter() {
+            let flowable = just(42);
+            flowable.subscribe(MockSubscriber::new(i));
+        }
     }
 }
