@@ -12,6 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+mod iter;
 mod just;
 
+pub use iter::from_iter;
 pub use just::just;
