@@ -12,8 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-mod flowable;
-mod processor;
-mod publisher;
-mod subscriber;
-mod subscription;
+pub mod flowable;
+pub mod processor;
+pub mod publisher;
+pub mod subscriber;
+pub mod subscription;
