@@ -14,8 +14,15 @@
 
 use crate::{subscriber::Subscriber, subscription::Subscription};
 
-#[derive(Default)]
-pub struct MockSubscriber;
+pub struct MockSubscriber {
+    request: u64,
+}
+
+impl MockSubscriber {
+    pub fn new(request: u64) -> Self {
+        MockSubscriber { request }
+    }
+}
 
 impl Subscriber for MockSubscriber {
     type Error = ();
@@ -23,7 +30,7 @@ impl Subscriber for MockSubscriber {
 
     fn on_subscribe<S: Subscription>(&self, s: &S) {
         println!("on_subscribe");
-        s.request(u64::MAX)
+        s.request(self.request);
     }
 
     fn on_next(&self, t: Self::Item) {
