@@ -12,6 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+mod iter;
 mod scalar;
 
 pub trait Subscription {
@@ -19,4 +20,5 @@ pub trait Subscription {
     fn cancel(&self);
 }
 
-pub use scalar::ScalarSubscription;
+pub(crate) use iter::IterSubscription;
+pub(crate) use scalar::ScalarSubscription;
